{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Lab 4 -- Validation Splits and DataLoaders in PyTorch\n",
    "\n",
    "## AMPTH 207: Stochastic Methods for Data Analysis, Inference and Optimization\n",
    "\n",
    "**Subtopic:** Train/Validation splits on DataLoaders in PyTorch\n",
    "\n",
    "**Instructor:** Rahul Dave\n",
    "\n",
    "**Blame:** Any blame for any errors in this document goes to Patrick"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 42,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "from IPython.lib.display import YouTubeVideo\n",
    "\n",
    "import numpy as np\n",
    "import torch\n",
    "import torchvision\n",
    "from torchvision import datasets, transforms\n",
    "from torch.utils.data import Dataset\n",
    "from torch.utils.data.sampler import SubsetRandomSampler\n",
    "from torch.utils.data.sampler import SubsetRandomSampler"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Defining our Dataset\n",
    "\n",
    "We'll start by defining a dataset not too disimilar to MNIST but a lot simpler.  We replace our (28, 28, 1) ndarrays with (2, 2, 1) versions.  We also implement the ability to handle transforms just so our class fits in with the MNIST-like Dataset/DataLoader scaffolding in torch/torchvision."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "class MyCustomPixelDataset(Dataset):\n",
    "    \"\"\"\n",
    "    This dataset is a toy dataset that acts like 2x2 version of MNIST\n",
    "    with the trace as labels.\n",
    "    \"\"\"\n",
    "    def __init__(self, size=1, transform=None):\n",
    "        super(MyCustomPixelDataset, self).__init__()\n",
    "        \n",
    "        # size determines length of dataset\n",
    "        self.size = size\n",
    "        \n",
    "        # generate random 2x2 matrices with values in [0, 255]\n",
    "        self.matrices = [np.random.randint(256, size=(2, 2)) for i in range(self.size)]\n",
    "        \n",
    "        # our dataset will be a list of (ndarray, label) tuples where the label is the trace\n",
    "        # reshape our matrices into (2x2x1) ndarrays so that transforms.ToTensor()\n",
    "        # has the appropriate expected shape\n",
    "        self.matrices = [(np.reshape(np.array([matrix]), (2,2,1)), np.trace(matrix)) for matrix in self.matrices]\n",
    "        \n",
    "        # if we're passed a transform then apply it to the first element of our tuple (the input)\n",
    "        if transform:\n",
    "            self.matrices = [(transform(element[0]), element[1]) for element in self.matrices]\n",
    "        \n",
    "    # length should just be the size although we don't validate size (i.e. should be an int > 0)\n",
    "    def __len__(self):\n",
    "        return self.size\n",
    "    \n",
    "    # implement __getitem__ as the indexed tuple \n",
    "    def __getitem__(self, index):\n",
    "        #assert 0 <= index <= self.b - self.a\n",
    "        \n",
    "        return self.matrices[index]"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**If we look at an example small instance of our dataset, we see that it correctly handles the transforms.ToTensor() operation and matches the structure of the MNIST dataset although we have scalar labels as the trace of the original random 2x2 matrix**"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 26,
   "metadata": {},
   "outputs": [],
   "source": [
    "mydset = MyCustomPixelDataset(12,transform=transforms.ToTensor())"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 27,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "[(\n",
       "  (0 ,.,.) = \n",
       "    0.1020  0.5059\n",
       "    0.8706  0.4314\n",
       "  [torch.FloatTensor of size 1x2x2], 136), (\n",
       "  (0 ,.,.) = \n",
       "    0.8000  0.4627\n",
       "    0.3373  0.1529\n",
       "  [torch.FloatTensor of size 1x2x2], 243), (\n",
       "  (0 ,.,.) = \n",
       "    0.5922  0.5765\n",
       "    0.4745  0.0471\n",
       "  [torch.FloatTensor of size 1x2x2], 163), (\n",
       "  (0 ,.,.) = \n",
       "    0.1725  0.2627\n",
       "    0.9294  0.5765\n",
       "  [torch.FloatTensor of size 1x2x2], 191), (\n",
       "  (0 ,.,.) = \n",
       "    0.4314  0.8667\n",
       "    0.1412  0.7922\n",
       "  [torch.FloatTensor of size 1x2x2], 312), (\n",
       "  (0 ,.,.) = \n",
       "    0.7373  0.4000\n",
       "    0.3216  0.5725\n",
       "  [torch.FloatTensor of size 1x2x2], 334), (\n",
       "  (0 ,.,.) = \n",
       "    0.3333  0.2745\n",
       "    0.4706  0.7882\n",
       "  [torch.FloatTensor of size 1x2x2], 286), (\n",
       "  (0 ,.,.) = \n",
       "    0.8510  0.0667\n",
       "    0.3725  0.6000\n",
       "  [torch.FloatTensor of size 1x2x2], 370), (\n",
       "  (0 ,.,.) = \n",
       "    0.3412  0.0784\n",
       "    0.9922  0.9490\n",
       "  [torch.FloatTensor of size 1x2x2], 329), (\n",
       "  (0 ,.,.) = \n",
       "    0.5647  0.9020\n",
       "    0.7137  0.3490\n",
       "  [torch.FloatTensor of size 1x2x2], 233), (\n",
       "  (0 ,.,.) = \n",
       "    0.2392  0.5647\n",
       "    0.1490  0.6196\n",
       "  [torch.FloatTensor of size 1x2x2], 219), (\n",
       "  (0 ,.,.) = \n",
       "    0.8588  0.3569\n",
       "    0.8784  0.8627\n",
       "  [torch.FloatTensor of size 1x2x2], 439)]"
      ]
     },
     "execution_count": 27,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "mydset[:]"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Defining our DataLoader\n",
    "\n",
    "We'll now define a DataLoader with a batch_size of 4 and shuffle set to be True.  If things go as expected when we loop through our epochs (we only define two here just to show the functionality) and iterate through the DataLoader, we should see our batches of 4 and they shouldn't come out in a defined order.  Our data should come out in different orders (and different batches) in each epoch."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 28,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "mydset_loader = torch.utils.data.DataLoader(dataset=mydset, \n",
    "                                           batch_size=4, \n",
    "                                           shuffle=True)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 29,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "0 0 \n",
      " 136\n",
      " 243\n",
      " 370\n",
      " 312\n",
      "[torch.LongTensor of size 4]\n",
      "\n",
      "0 1 \n",
      " 334\n",
      " 163\n",
      " 191\n",
      " 233\n",
      "[torch.LongTensor of size 4]\n",
      "\n",
      "0 2 \n",
      " 219\n",
      " 329\n",
      " 286\n",
      " 439\n",
      "[torch.LongTensor of size 4]\n",
      "\n",
      "1 0 \n",
      " 136\n",
      " 329\n",
      " 191\n",
      " 233\n",
      "[torch.LongTensor of size 4]\n",
      "\n",
      "1 1 \n",
      " 370\n",
      " 334\n",
      " 312\n",
      " 286\n",
      "[torch.LongTensor of size 4]\n",
      "\n",
      "1 2 \n",
      " 243\n",
      " 439\n",
      " 219\n",
      " 163\n",
      "[torch.LongTensor of size 4]\n",
      "\n"
     ]
    }
   ],
   "source": [
    "for epoch in range(2):   \n",
    "    for batch_index, (inputs, labels) in enumerate(mydset_loader):\n",
    "        print(epoch, batch_index, labels)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Sure enough our label clusters come in different orders and organized in different batchs in each epoch.\n",
    "\n",
    "### Splitting out a Validation Set from our Dataset\n",
    "\n",
    "Our problem is that we're given a dataset but not necessary a validation set.  How do we split out a validation set while still being able to use the convenient dataset/dataloader scaffolding that PyTorch provides?\n",
    "\n",
    "We'll take the following approach:\n",
    "\n",
    "* Split our dataset into training set and validation set\n",
    "* Use the indices of the split to create PyTorch Samplers\n",
    "* Feed that sampler into our DataLoaders to tell them which dataset elements to include in their iteration\n",
    "* Iterate over the appropriate DataLoaders in the training/validation loops\n",
    "* Gnome underpants\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 45,
   "metadata": {},
   "outputs": [],
   "source": [
    "## define our indices -- our dataset has 9 elements and we want a 8:4 split\n",
    "num_train = len(mydset)\n",
    "indices = list(range(num_train))\n",
    "split = 4\n",
    "\n",
    "# Random, non-contiguous split\n",
    "validation_idx = np.random.choice(indices, size=split, replace=False)\n",
    "train_idx = list(set(indices) - set(validation_idx))\n",
    "\n",
    "# Contiguous split\n",
    "# train_idx, validation_idx = indices[split:], indices[:split]\n",
    "\n",
    "## define our samplers -- we use a SubsetRandomSampler because it will return\n",
    "## a random subset of the split defined by the given indices without replaf\n",
    "train_sampler = SubsetRandomSampler(train_idx)\n",
    "validation_sampler = SubsetRandomSampler(validation_idx)\n",
    "\n",
    "train_loader = torch.utils.data.DataLoader(mydset, \n",
    "                batch_size=4, sampler=train_sampler)\n",
    "\n",
    "validation_loader = torch.utils.data.DataLoader(mydset, \n",
    "                batch_size=2, sampler=validation_sampler)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Testing our Validation Split\n",
    "\n",
    "OK -- we should have accomplished the first 3 items on our agenda:\n",
    "\n",
    "* Split our dataset into training set and validation set\n",
    "* Use the indices of the split to create PyTorch Samplers\n",
    "* Feed that sampler into our DataLoaders to tell them which dataset elements to include in their iteration\n",
    "\n",
    "Now we kind of glossed over an unexpected problem.  If you define any kind of sampler, you lose the ability to designate shuffle as True in your DataLoader.  For this reason we defined our sampler as a SubsetRandomSampler which should ensure shuffling by its very nature.  If all goes as expected, we should be able to iterate through our train_loader and validation_loader and get segmented results -- elements in the validation loader are not in the train_loader and vice versa.  Furthermore, we should see random shuffling batches from our train_loader just as if we designated shuffle to True.\n",
    "\n",
    "let's test our train_loader:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 46,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "0 0 \n",
      " 163\n",
      " 334\n",
      " 136\n",
      " 219\n",
      "[torch.LongTensor of size 4]\n",
      "\n",
      "0 1 \n",
      " 243\n",
      " 329\n",
      " 370\n",
      " 312\n",
      "[torch.LongTensor of size 4]\n",
      "\n",
      "1 0 \n",
      " 329\n",
      " 334\n",
      " 163\n",
      " 243\n",
      "[torch.LongTensor of size 4]\n",
      "\n",
      "1 1 \n",
      " 370\n",
      " 136\n",
      " 312\n",
      " 219\n",
      "[torch.LongTensor of size 4]\n",
      "\n"
     ]
    }
   ],
   "source": [
    "for epoch in range(2):   \n",
    "    for batch_index, (inputs, labels) in enumerate(train_loader):\n",
    "        print(epoch, batch_index, labels)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "and now our validation_loader:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 47,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "0 0 \n",
      " 233\n",
      " 191\n",
      "[torch.LongTensor of size 2]\n",
      "\n",
      "0 1 \n",
      " 439\n",
      " 286\n",
      "[torch.LongTensor of size 2]\n",
      "\n",
      "1 0 \n",
      " 191\n",
      " 233\n",
      "[torch.LongTensor of size 2]\n",
      "\n",
      "1 1 \n",
      " 286\n",
      " 439\n",
      "[torch.LongTensor of size 2]\n",
      "\n"
     ]
    }
   ],
   "source": [
    "for epoch in range(2):   \n",
    "    for batch_index, (inputs, labels) in enumerate(validation_loader):\n",
    "        print(epoch, batch_index, labels)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Testing Conclusions\n",
    "\n",
    "RESULT!! No overlap! Now because we use SubsetRandomSampler for both our train_sampler and our validation_sampler as a side effect we get random shuffling on our validation split.  It's not ideal, but not the end of the world.  Unfortunately there isn't a SubsetSequentialSampler class.  We could write our own sampler class (they're quite easy to implement) but since the downside of random shuffling in our validation split aren't onerous, we'll just use the SubsetRandomSampler as a base class for both samplers.  We have achieved our final two objectives:\n",
    "\n",
    "* Iterate over the appropriate DataLoaders in the training/validation loops\n",
    "* Gnome underpants"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Train/Validation Splits on the MNIST Dataset\n",
    "\n",
    "With the above infrastructure in place, we can construct some validation boilerplate code for HW4 Questions 2 and 3 to allow us to create validation sets for MNIST.  Fortunately we don't have to do anything special for the test set, the MNIST code in torchvision already at the right size.  As is, out of the 70K imates in MNIST, the torchvision MNIST dataset  gives us a 60K/10K train/test split.  For the HW we want a 60K/10K/10K train/validation/test split.  You should be able to use the below boilerplate."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 48,
   "metadata": {},
   "outputs": [],
   "source": [
    "## Define our MNIST Datasets (Images and Labels) for training and testing\n",
    "train_dataset = datasets.MNIST(root='./data', \n",
    "                            train=True, \n",
    "                            transform=transforms.ToTensor(),\n",
    "                            download=True)\n",
    "\n",
    "test_dataset = datasets.MNIST(root='./data', \n",
    "                           train=False, \n",
    "                           transform=transforms.ToTensor())\n",
    "\n",
    "\n",
    "## We need to further split our training dataset into training and validation sets.\n",
    "\n",
    "# Define the indices\n",
    "indices = list(range(len(train_dataset))) # start with all the indices in training set\n",
    "split = 10000 # define the split size\n",
    "\n",
    "# Define your batch_size\n",
    "batch_size = 64\n",
    "\n",
    "# Random, non-contiguous split\n",
    "validation_idx = np.random.choice(indices, size=split, replace=False)\n",
    "train_idx = list(set(indices) - set(validation_idx))\n",
    "\n",
    "# Contiguous split\n",
    "# train_idx, validation_idx = indices[split:], indices[:split]\n",
    "\n",
    "\n",
    "# define our samplers -- we use a SubsetRandomSampler because it will return\n",
    "# a random subset of the split defined by the given indices without replacement\n",
    "train_sampler = SubsetRandomSampler(train_idx)\n",
    "validation_sampler = SubsetRandomSampler(validation_idx)\n",
    "\n",
    "# Create the train_loader -- use your real batch_size which you\n",
    "# I hope have defined somewhere above\n",
    "train_loader = torch.utils.data.DataLoader(dataset=train_dataset, \n",
    "                batch_size=batch_size, sampler=train_sampler)\n",
    "\n",
    "# You can use your above batch_size or just set it to 1 here.  Your validation\n",
    "# operations shouldn't be computationally intensive or require batching.\n",
    "validation_loader = torch.utils.data.DataLoader(dataset=train_dataset, \n",
    "                batch_size=1, sampler=validation_sampler)\n",
    "\n",
    "# You can use your above batch_size or just set it to 1 here.  Your test set\n",
    "# operations shouldn't be computationally intensive or require batching.  We \n",
    "# also turn off shuffling, although that shouldn't affect your test set operations\n",
    "# either\n",
    "test_loader = torch.utils.data.DataLoader(dataset=test_dataset, \n",
    "                                          batch_size=1,\n",
    "                                          shuffle=False)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "You're done now! :-)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 43,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/jpeg": "/9j/4AAQSkZJRgABAQAAAQABAAD/2wCEAAUDBAgJCAgICAgICAgIBgUGBwUIBwcICAcFBwYHBwcH\nBwcHChALBwgaCQcHDSENDhERHx8fBwsiJCISGBASExIBBQUFCAcICAcHChIIBwgSEhISEhISEhIS\nEhISEhISEhISEhISEhISEh4SEhISEh4SEhISEhISEhISEhIeEh4SEv/AABEIAWgB4AMBIgACEQED\nEQH/xAAcAAABBAMBAAAAAAAAAAAAAAAAAgMEBwEFBgj/xABXEAACAQMCAQUIDgcECAQGAwABAgAD\nBBEFEiEGEyIxQQcyUVRhcZTUCBQYI0JSYnKBgpGSk6IzRKGxssHCJNHS8BU0Q1Njc+HiFoPx8nSj\ntMPExRdVhP/EABoBAQADAQEBAAAAAAAAAAAAAAABAgMEBQb/xAAoEQACAgEDAwQDAQEBAAAAAAAA\nAQIRAxIhURMxkQQVQWEFFFIiQjL/2gAMAwEAAhEDEQA/APGUIQgBCEIAQhCAEIQgBCEIAQhCAEIQ\ngBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAE\nIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhC\nAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQ\nhCAZxDEu/wBzJr3jekekX3qcRU9jTrq4zd6TxIHC4vu3/wDxyaJ3KShLtqexp11Rk3ek/RcX3qci\n1fY762oybrS+HYK97n/6SQyafBTuYZlpf/wdquWHtnTgVbac1rrifJ/Zple4Xqx/WdO/Gu/VYGh8\nFWZhmW5T9j9rJ6rnTPx7v1WOL7HjWj+taX+Pe+qRaGh8FP4hiXIPY66341pf4976pMj2Oet+NaV6\nRe+qSLROh8FNYhiXhZexm1p+vUdEpY7atzqIB+lLEyQ3sXtY/wD7jk8fNd6qf/10alyND4KHhiXi\n/sZtYHVqeht5q2q/z06Qbj2O2tIT/atLbHata+x+azEa1yT0pcFOQltr3AtYJx7a0wHwGtej/wDE\nj49jxrXjel/j3vqkjXHkdKfBTsJcfudtb8a0v8e89Umfc66341pfpF56pI6keR0p8FNQly+501vx\nrS/x731SHudNb8a0v0i99Ujqw5HSnwU1CXJ7nXWvGtL/AB731SHuddb8a0v8e99UkdWH9E9GfBTc\nJcnuddb8a0v8e99Uh7nXW/GtL/HvfVI6sP6HRnwU3CXL7nTWvGtL/HvfVIr3OWt+N6V6Re+qR1of\n0OjPgpmYlz+5y1vxvSvSL31SHucdb8b0r0i99UjrQ/odGfBTEJcx9jnrY/WtK9IvfVJj3OuteNaX\n6Re+qR14f0OjPgpqEuX3OmteNaX6ReeqQ9zprXjWl+kXnqkdeH9Doz4KahLl9zprXjel+kXnqkx7\nnXWfG9L9IvPVI6+P+h0Z8FOQlxN7HfWh+taZ+Pe+qTA9jxrXjOmfj3vqkdfH/Q6M+CnYS5Pc6614\n1pf4956pD3OuteNaX+Pe+qR14f0OjPgpuEuX3Omt+NaX6Re+qTI9jnrfjWl+kXvqkdeH9Doz4KZh\nLn9zlrfjWl+kXvqkS/sddaH61pf0V731SOvD+h0Z8FNQly+501vxrS/x731SHudNa8a0v0i99Ujr\nw/odGfBTUJcvudNa8a0v0i99UmPc66141pf4976pHXh/Q6M+Cm4S4/c7a141pf4956pFr7HPWz+t\naX+Pe+qR1of0OjPgpmEuj3OGueNaWfJ7YvfVI4vsbNcP63pPpF96pHWh/Q6M+Ck4S9bb2L2vv1Xm\nkfTcX3qcau/Yy67Tba15pOcA5W4vsf8A0cdaH9Doz4KPhLo9zfrnjelekXvqkwfY46343pXpF76p\nHWh/RHSnwUzMS6Pc4a343pXpF76pM+5u1zxvSvSL31SOtD+h0p8FLwl3J7GbXT+t6R9Nxfepxz3M\nOveOaR6Rfepx1Yf0OlLgo2EvL3MOveOaR6RfepzHuYde8c0j0i+9Tjqw/odKXB66zns+nqjOoU/e\nzj5J6vlTFvq1s+NtekcjgvOAN91jJVV1ZTgqeHAA5zOnRRWL3GK6bkzjrGZq7uh723Djt4TeU0zS\nX5sh81lT5Mgyko2aqVGg0jThUW56OSX68cRupbuj96V9SqVFypY5DMMnrHSlvckqHvtZPjU6LY+b\nvRv6ZWuv2Bp3Vwg+DXqjHg6W6NDqyNbukMWerunBuIHbN5p2v0Xbb0t3mM0dKyzjh9M2Wgad0nwv\nSV2QtjjMnwbpbWdNb3NM9v04IkxAsj2djgdX7JsaVr5JRoIb2iMVbbtXgf3zZC3hzEqScxc1K652\npk+GQHr3/ZSHnJH987GrQ8n0xg23n+2UaZpFructb0K5bfURc573PCbVAccQR5PBJ5t4e1l/yZlJ\nF9SIYEziSjbDyzHtaZtblk7I2R4f2zJMkcwPBDmJSiSKTOe5S63WpPzNtT5ypt3M5PRRt3U3V8X8\n06k0ZXXK9ru3uuaomm/Pu1YDm8uN3+93fJ/hlowsmwtOV93RqgXlNebZgCyj9GvhXaTunbW92tRQ\n6HcrDcG7CJTl7fXJqstXjx2FQOh+WWF3K3L2lRWyRTrsqE9isqtj80iUK+SWdMGbwD7YoEyRzQi0\npzIEXDQKtJopwNKVYNHWqnJGTwODM0G3HrPDhJF7YOWO1CQTncCMRyw09gcsNvyc5kAWtExxLeTE\npR0JIsWQfa/nhzAk/ZElZDJIJoCMXNWlTGajog6gWZVk6/qCnTeoepKbufmqu5v4ZS2tVK95VavU\nqYpszczS3cFRW29Ffqy8Y2C1rK7pVhmjUWoO0qc4+dJS05UfJerUtLqi6MWRqqUqlLOMo/Rz9DS5\nAslxoDIpxYSPBIrZKgY2eSIelJe2Iqr1QQR9kObj6rApKixjm4g0pK2mIYSUgRjTj1GnwmSI5RPA\nyyRFilpx5Si9JyAPKZz+q8okosaYBL7c/wCfuzV22oVLh2V92Nh2U1P8TS9EPYsDRtVp1axo08HF\nJnLD5LKv9URr36b6o/qnK9zEn29UDeL1QBn4tVJ1Gv8A6X6iSCLNey/3/miCI65GB83+po2TIZIk\nRwRCxxRLLdkMn2w6Mkxq272PIsvVENkW9uCm3Aznd+Xb/ikCvcO3b9Ef1vgaf/m/0TXM8rYM1+Sd\nJxlVA8BR+P1t0iPyVuE/Q1aqjtXiR+Uzs1o9NkHwXdPzTc6RSxWpfOwZ9NoR43Voq6g2oUaYRX37\nS4PSDE9LcvfcYu1166pE89bFlPWwBGJYvdHpBbQsq4K11bIGO+b/ALpqNLSlXJGzGabMCDjPxZDx\nfJaOZN0a3uf6mlxe1NqsvvByDjj093wfnTUcq9NH+kLpTnBNGoD89F3fmmz5IViL63yAN7VqZYAA\n9Ftqjcsn8tLJmv8AoISWt0bgOvbu3fZ0ZGnaidSu0cjRs8dmfBNzycth7YrrjG5bapx+VS/xboha\nOOB+kTZ6MmLlT8a2RT50dlmTxo2U/wDNs2gtAOyLFv8A5xNmtOJ5qQ8a+CvUNc9CINGbJ6caalKP\nEWWQ1r0RGmozZPTjRpTKUGXUkzWtQiDSmyNOINKZSiaKRrzSmObk5qUSaUxlE0TRD5qYZJMNOIdJ\nm4l1LYgOk53lZRJRgFTiuBWfPRX4Xe995p1b05XXKDlrbVLj2io6JZ6Zvc7V51d3QXz+GI/JeMtz\nhqtUIxG5WwzcQMSzuRlOlRskO+lhmepUqrUBQOz9EFvjbcSn+UiilVqqpyodsNn43ZOeS/qhDTWo\nwpMyu1EHCu696WWavFqRpOWx6hA/6R+msoXkx3Q7225tKjc/QXapo1OLil4EfrX6cy7+TmrUby3S\nvQOVYYKk9JX7UdfgsJzZMTiZKdk8LMhY4ixarMaLWM7JkU5I2TIWVJsYFOLKx7ZApAsj7Zhkj5WI\nIkMg1+p0S9Kqg4lqVVMH5SMsqavZrzVEHo80GV0xxLruyPvS5aq8JW/dOshSKVE6Iqbw6jqLr2zb\nEWRyWmUkNYYJINWjhSflrLm34lIcjdQAvKLP3oq4JJ4DcrLmXHb3AfvWDeUEGXnDfYMkV7wL1gnz\nDMa/0unxHxjJbHVMk4Jz1ALNe7Dm6vEliavX2fBUfZMmmu5VM6GnxAPhGRE1FirHjTT/AJaH8qxy\nqsq0TY0BMlYsCK2SKFjO2IKyTzcbIkpCyGRF0RwbzRbU45SpHjjtHVLpEHCcp6WLj/y1/iaK5OVV\nR3LHHQXB+tOi1fQedrCo9RaabNp49I9Nm6M2Wk8n7amAy0+dJ2kVHAb7q9UsUcvg0/c6pMb1qmx+\nbNOsOdx0dzMrKN31Z0/KAgMCeA28STjCzZWCNkdgAwFxgCcF3YqS1qiU8suy2Zzhiqlmdtu5fhd6\nv3pFbkxVujYpd0nyKdRXK9YVgxHztsVKS0KrWtrugytjfXpUyM5DIzqpDfbLZuNbt1x78nFlQDOS\nXbs6MmUaL0bUGOI00TazRB4sevBABgNap9m4/RKrZkHZWp6IkpZyNvynRRjm2PlyBN7oOpi5RnCl\ndr7CpOc9FW/ql07Ksb5QD9GeHW4/hmqzJnLa4NOkjAcdzcPuzjTq1Q+TySH3CLa1DoXFb/mZ8HfK\nrf1SZp16BUp5HwkH5pA1dy1YvgrvSk+0jj8X+mYtj0lPgZW+60+rPnbN9y3tS9pcL4F3j+Kc5yRp\njNI+FNuPqzs9Zp85Qqgcd9DgPDuScNyTqZSl5HZCZX4LRNNZe93tLqGzVKqkdWEer0Z2XKys1G5t\naiHBalWoNwByrf8AtnH68pp3tZvi3dvcDHHvtv8AVunYcuV3U7Spx4VkX6rI0hrYvq2NBd0gSDgZ\nJyeHW0csFArUGx21kP5WX+qO114DzxsHBpHwXVL7GVl/wyrW5rGT00dRiYxHEHAeUQIhozeww4jL\nLJZWIdJSSJiyGyRBWSCsSRM5K9jaLIrJEFJJdY2VnNKBsmRmSJ2ySVmNsxcWXTIpWJZZJZYh1mLT\nNoyOE7ovK9dPUU6a77l1yF7ET47fG80oq731lr3BJzTek5AHD31mXr+DxX80s7up2obVCTx22tuQ\nvzt/+GcdVKhHojavOhhzeMb3VWZfrTSFI3jBtXZxF9fu64Pg77PXG76gaRpBjxa2o1yPi8701Vvl\nbSssulydVtOtaVejRSh7Ta8q371NlxQurmq3NGltyaqldgKkYnB90PTalrcruZHStRpVLeqhyGt0\nRaS7l61YMjAj5Jm6d7IwlJ2amjW4/wApY/cX140L5aDvijc7aZUnoit/sj4N25sfWlVLUmxsLsqy\nupIZWV1YdaurbgYlBNOyilTPYIEdVZyvcw5SrqVmlRv09ILSuFwBl/guq/FK/wA52IWeVOOl0bxl\nYgJFhIsCKRZm0WGtkNsk83wH743Xo54dKNIsjkTUazrFG3zuILAZKZA+98Wba7YUqb1H4KisxaUn\nrOpBmubqsN4eqaVGiScNV+GW2nvQNv0tNsOJydInsrZ0tXuhEOx5lDSB6t+GH04/lOZ5c8s0ulp0\nhTCopZic7m39732B8FuqcPcXhOePWcnsmuuK3lnvej/GLvOmc2f1NbQJTXKqcqeOciZstRqo2+nV\nqI2cllqOp/KZpnfj9MlLdIFwq8TjLE5nd+pjhvpOZ55T7s7PQuVlwlVDWrVa1POHpNVc7l/xS7NN\n0+2dFqoN4dQ4YneCrfOnmK2ucsJffcY1DnrJqTNlqFZgB4KLqrL+bf8Asnk/ksCpSjtR0embdps7\nZKYHUMdgAmKw4STtiKy8J4rVnVZCDHsUxxA3xftjyCPAStEkK4JRC7kKqqzFicAKs448vrHneazU\n7/bzoXo+f5sld2SpUXThsJANzSR8HGU2Pwb5PRlN2NoznOcDPfZxNccLuxVnomhhgGHFSqsDjGVb\nvTJlrSGfozwnL9zqpcVbcVK1UOoHNIo4sdvRy/ABeiq4Az5TOytE4jzNJcaZWTpiaVqDuyM96RkZ\nxJlKhgYHDyRygnE+aQ2rP7bNLPQFurhcDv8Aftzu65ejOyUiYPX5+Mrvur6VcNVWrRU1Q9LYyAgF\nGRmY98e9Ksv3Z22hcat7nsuaWOPV70s4/u2avVt6FFKJCvVNUbj17F27sfekabNIPcpbVl2jp8HB\nyFB47lb8setdWSrWtl7w/wCkVrFScqEd07fqzR687qcu2WJbLeFppjW457Qc5B4zdQtCbaLlrv02\n8G98fejikTneS2pC4ogk5dOhU8Jb4Jm8RpxONNmiJSmdl3PP0Vb/AJ/9CTigZ2vc6/RVv/iP/tJJ\niUkOd0ce8U/K7f0yvGMsXukj+zUz/wAX+mVy0l9yEXlqy5Fu/YaG3PzW/wC6RVbEVyoueZtqZxnZ\nWekRnHxv7pzS8pF7UHmD/wDSfWOOx84WvSO6jSPYaSjP5ZX+gdFqqfEuXxnr27p2PJa656xoVB1Z\nrKOOe9qssr7W7l7e8uQp4Gpux1fKlEjSPZj/AC1pYu6p+PbUX+srTqNaYVNNpVOvHtdwfq7ZzPKx\n97WlT/e2VUk+FtqNidBYtv0YduKDeXDI3/bDRPZWQCQQOOZispFNmA4q1Jx9Wqv+Kc7aXD70OeG7\nGM8J1lhhjtYZVlwR2GVexePY3dA9FfmrHDiMomBjJ4eWRbsZVuJ4DrzKuQ02TTgSHf3O1W2YLhCy\nqQSDt+bNeap+MeHljLkk9Z+2YyypfBpHGzcUaoZQ2RxVSRnqbb1RNQjw/tnBVblxVcBivSbGDjDT\nja3Ke+3MvtmqAGZODYPRbbMlnUnVGvTpWXUxEQWH+SJTKa5ct13NYn/nOP5zJvap66tQ+eo5/nLt\nWit0XE9RB1sB9IjNW8pDrqUx53AlQis3aSfpzAkeCU6ZfWWtU1W2HXXpj64karr9mOu4X7HP8IlZ\nO37uEZrHHX2zPpF1IhcvNYt31W5qc970LC1WmxDqGq7tzdFhn40rLX9TR66FelTRlJAJG5d3S2zY\n8vqv9oqL8mjn7m7+qcVXq9cdI6I56jTLu5G6RRvWa8oXPQrUK1ve0XZCaFFW3Uiox2Ki4J8/hxVn\ndR14X2p16yfoUK21svHAtaC7E2+fbn606TkXotRKNSvSvubW5tRQrImABRr7kbe2T0h0uOARxnL8\ns7WypBKds6u61HWoytv3JtXac9X0dkRg0zLVZze4x+3qyKZJ0rBr0gwyrVUUj5LNt/qmzSrcrZ2P\nIblFWsa4rUX27hzdQYDA0m+S3gaXDS5UXjAEVzgjIKqgH7p59FJ6VR6bdaOyEY+K0s7kHe85b4PE\n03258KdFlnHPEm22jSMqO7XWLlu+r1PNvI/hnccjK7PbAsxY844LE5P3pW1EywO58f7NUHxa2fyz\nmlBJdjRT3o6pB0R86K2yJpd0771ZNoSo6g4I3L4ZsQvCYqLsu2Vl3XtZ2qtsp4gpUqcettrbR91l\nMp2vTqVmFOmrO7thKSgszHyLO45eLXudQq0hTqPWNZlWmtN8su3am1V+Dt2yxeQHIilYIKtVVqXb\nLxq4B5lfiUv5kTfFPQ7+S17NHnPWdCu7anSqXFF6SV2rLT3jax5pl3bl+D33b1zRVzPUXdl0ZbnS\nq525e3U3VMgcQyL0gvnXdPLtyOztn0PofU6lv3POzR3sh1GmA8xVWJprPRnujCJu+TGlPdXCUKZx\nUdKxpqfhuiM6p9OMSwu5NqftW7QMcU6x5moDwwzdX5ts5DuYVNmraeT40i9eO+3L/VO67ouh+0r/\nAH0/0dzm4p44bKu731PobafrTwPyL/5PS9MlVstXlBf1aHMimEzVqMhLgkDobl27SI3o2o1awrLV\n2ZpsijYpUFWRW47iZF5ONT1KyoPUZhUottZgcHnVXbn6Vm4s9KSgH2ZJcqWYnJO3vZ4bVGzdD1BZ\npOUouucHMu+zYoNJAc7vDOgoDhHwnb+2QibOKu7inQ0+4fUN9amQuKFQcTV+Ci7v3yorK9ovXJak\nFpmpv9q0m2e9L0tiM3et0euWl3d6TNYUGXqW8XePI1J1Xd9aU+NJrhDVPRAXcBnpGdOONEW/g9Cc\nkltvalFrNStB0Woikkuu7vg+74QPAzobReIlYdxrUGWyrNc1NlEV0FB3OA25W50J8ndt+9LPsSDt\nIOQRuDA8CrSJLczk/lkxBxPmmsqY9vee0Yfdqr/fNvTXj9GZrL8YvaXltrgfdZJaigzon+s3y/8A\nFtW/+VK+7t/G6tUOMLbc8Rw3fp2/wywtJ/1q9+bat+VpTndI1Pnr56jPv2U0oL1YVF3thfpZj9aV\nunR2ekS1W/grzXaO7KjJGSwYnhs3LtOPjDpA4nKkdILkcW27usDpTotbuTtK9pLFuOdrfCKN8HPa\nJza/pE6+/T+KdWNUjT1UoyktJ3vJOktKoKa/DVtzdpKrunWIZzmgU/fXb4owPrToUnDPuyGkiUh/\ndO27nP6Gt/8AE/8A2knEU53Xc7H9nqHw3DfwKsRic+Rod7pP+qIf+Nj8rSuJZHdJ/wBTX/np/C0r\nVjElWxEXZZHKHW1urepTFKou6vzwfIwvxh0Zyb2Q+Mftln3ukACpZo+yk1K1IbGSH+EfndCRKHIR\nB39djwXqp9c+sadHgXHgb5BcpLa1s/a9Y1Ny1arghN67X+maLlNqdGtc1KlMnYQpLMNvS72WFyb0\nSjao6D3zc24l0T8vCablvpdA17YuoSm6tSqc0EVizNwxwx3xlEmXTVbI5/UNUt6lCwRKqtURtjrn\nio27f6Zv+SOo0TZVrZ6iqytWADEKNr7m6Ma1/k7SWhbIgf3hKzJnYXbpI7BmX4XX4I1o2mW53UWQ\nNw591I6tzdAfQv8AFDRLqqNDbDivkbM7DTGG5PPj701nJrk9bsazoTsSpzKrk4DL3x/Nj6sXX051\nqFQdqh8Dic7d0zki0XwddjhItfvW8zRFOkwAG48BjMQQeOfBMWWSdmuMQ5mXMbczjl3N12OX1E7b\npvnqfvSutVG24rL4K9YfnaWHyg4XKnwqjfmZf6ZwHKkAXVXq4srfWZVZpzYn/uR0ySURikfPwkwV\nOyaunU8Ek0ak9KHY5GjZU6kec/8ASQqb5knOQJeig454Dw464y4zHeyNFJVosvs4zugaE7j2xRBZ\ngFWrTGSSqrwdV+rK1rUiW2gHOcbccd0v1wcTn+UlCnTo1bgU050IyrVx0gz9DO760UWiU01SoBs3\nOBnim4gbvmxpZPu6GDjrjLUcCKNEyLHrLhVpnwVaTfddZlacl2NsWqU1AyWqUlC+FmdZSSpCmdZy\n504LVp11/wBsnSXt3ou3P3ds23czqdKrT8KowHzYrl/b+9Wx8Duv5f8Atjfc0pH2y/A45lstjgOl\nM5diyRYNJZ3nc4PQuF8tJsfenGUafmnZ9z1cPXHhoq2Pmt/1nJJbE9mdnb0hjqknbE2w6P0R0TEu\nyObVc7to3dj4G4fWiin+THokiQ1ZKbIV9bB6boRkMroR2FWXbPIfKzSzbXlzbkYNKu6/V75PylZ7\nFrEAcSB4OPXPPnd90jZepcLjFzSyQOvnaW1M/Zieh+PyVPT8GWRbFPXNORkHGbK5XEhbZ9G+xxru\nbLk1eChdW1c9VG4o1SMZJVXVmnoXuq2aV7CldphhSelUWpnroV+h0frFJ5vo0zPR3cpukv8ARBbO\nGJpB7KqG45baroVbzOPuzwvyUezO700tqRrO5FqYpLdI3xaVVV7Sysy4Xz7lndWGq88DlNuOps5V\nvmyreSlM219VpuOlTFZdnazUm34+nZO/0S/SvVc06RooGBWmShyrd8ej8r+KeLNV2O5xTTfB0VEc\nJKXqkanJK9UyRkzkO7Bbo+kVyx2821Koh8Lq21R+ZpS9lrdMUBTq53KNo4ZDp8H60tbu0VN1vQok\n9Bqj1CB1llXao/NKXuLETqhTVM7MPpMko64rZlqdyzTLe+t6zvv20n5mnRztVXZd2/onslr6Vbc2\nlOmDnYiIGPWdq7ZV3cEuqa0ri2x76HSuWz36MuzvfJ0fvS2rXrHnlmlexx+oi4un3JNPr+r/AFTT\n6ydt1buTgCldLuPVubbtE3CdY8zSPqOnrVam7Z9734XHBt23vvurL6VRzWcdrmoVLc3jDG97eyXP\ngZty5/L+aV3y25LraaZRvWdmua1whdSNoRGpMy09nxh4T8aXLq/JxLjeSzAutFCBjAVG3Lt4fKac\n13XNAa6tbaitTaabMwY8Q+1VXpfVkQhvuaxm0tjzTc0i3hJJ6pCqWppvTZ1IXnEOSMZXd0paKdz+\npt5znwpG5lULx3J8X7siXeh1aylLi4evhHVN4HRZulnoj4yzqapUTFtu2N6KmGfiMMqOB27W3cf2\nTc0xNRolnUoU1o1WDFAwLAY+F1TZipPMl/6Z1TZNRhidz3Ov9Xf/AJ7n+GV/Ted73Om/s58teqP4\nZpjS3OfISu6R/qY/56fwtK0eWT3R2/sP/n0f6pWZeJRRSMnR6H1FcXSH41LGPms3+KbJJrNe4VKL\neV1z91ps0bgPMs+ps8EdpTn+WKgm2Y9QuKSnzM3S6U3yGaHluv8AY3b4jUnJ8Cq6yAmxzWsLSQtn\n3otlh1smzo/WPRmhsg5qPVp5zcU6KU2x3rv1/ZtJ+rH7+6S6Vnp8Ut1RAwPB6rKufnY3SDyYv9uo\nUrU4xRtrhSez2w23d9i8JWRr3RuuS9JaT3luBwS4VgCcnayL/hjmp8KnV2KcxFm+3U7xOPSoW9Ue\nDvmX+mSdXXDDOOqUa2Jj3JtDioPkUyPXXEkaf3g8yxm565zM3To0lfvj55HZom7um550KYUFulnr\n8EQzzjydzePY57lXwq0W8KMv3WZv6pxPLOzJqc/uULsRdmeLPtnV90GuVpo4xkMwB7B0ZWuv8pbm\nsmfa1JUCIouVIIfaq9NRU4qx28fpmUYO7ideOUf+1aE0Wk6iCeoEzbdz56dWgxenTqOKjKxamARu\n2so6uku1uudtYIoIxTpKPCEyZqstbMxljXx2ODtaLkcFY/QTJ9Gxrnqo1T5RSc/yll2tLh1qPNTA\n/nNhSpt2ufMAB/KaLLZk4UVfS0a6bqoVePhpuP4hJVPk3eH/AGDfSQP5yzkt/lt5s4jwtx4W++/9\n8t1BSK1TkbeMO8Vfklxwmt5Vdz+7ezrYankJuFMEkttZWwv3Zb4t08v25mK9BdpwOO1h1SYz3Vkq\nOzo8bX2hV1Y5otn4uM/mWQ00SvUqLTWmd7NtC+D50vnlTap7YKFBlKKFVA7VVkcL55HurOmld3CB\ndnvaqBjFWr1flzOiWSCXZ2ZxjK92VVb9z24z0qtNcDLYGQv05m45Hcgmq39qisaiLWStXYDYyUaT\nqzFDnvj553epW+xBT/2jtl8HqX4I/fNz3JLX+1VH+JSdSfrqs4J5G3sdWnka7pHJKyW2pHmai/2n\naN9TdndSdv6ZqO5ZplsK1a3wN9dU5pmOSrpuYhfOuZZnL/S3ubemiDLC5pN9Ta6v+WVrpFg9OvbP\nS3F2W2uaZPA5ZXfC7fDzTrMZSZvFqiztN5NLTcPimwGco9PIM3tC1C9Qpr4dibc/WkleodWcLmKA\nlWYye4U0wMRwCIWOgSNJSxBESwjhExIaITNbqdiKpQkkFGYgA4B3be++7Kh7tOkXVR6DqDUC0WQU\nqYdtjqzMx+kbfuy7is4nljRbnsnvNnDwbtvSnR6OWnImWl2o8v6lZ1ATuRlwcHcpGJrxaMRkAnzD\nOJbet0Q29CARnjkdc0FlRCJVTonaVAx2d9wnpy9bXwc/SOMsLCs2NtJyM4DBDt+9L77glu1OyuUc\nbT7c3be3bzCLn8rTjNOo7aaD5OfvdL+csPuYnHthfJSb63SWcHqvUOcao2hHSzk+VFTmdad+oC5t\n3OOGVbaz/szLK0jTaK7nogYqFahcDG/o9Eyou6LldUue+75CD4VZFxtlodzG8arYqj9/Rbm93xkd\nd9I/cZR9WeW233OzV/mje0pJLAKSeACsxbsCyLS/ccTX8t+c/wBH3QpnDe16vHOOjt6XSlK3KlYd\n0XlVSvai07cE06DPurkY31W6PR+T0WnEVjk8PBxGfhSXd2tOgoVXLMwU1GJ4FvJIKU2ZgFBZmYKq\ngZLM3ehZvHsfR+haWFJs6ruVXJp6pbgHAcvSYZxu3I20fenoS26x555n5MJUp6hbEgq9O/tVKEYZ\nXSuqsGX709MUuvh/lvhS9M8X8jWvYmIvGPFI1SkhzwnRGOx5dkcGablhRzSR/iswP1ptg3V5Qsgc\npuNs3nT+KWS32CZXdxUO1wOGxuB+T2znRQ6R6+vrnQ1sbth+EeI8O2a64HSwBgDcp4fK65eW5tBn\nJX1UGo+OI3sIzz2I1aOaTNTdSGDuCCM/C6M5zlTrtWlXZEVdu1W4j4yzjljtm2uzaavrNSnwpjc3\nlPALOh7lvLepzwtawUK7MwcdYduz6ZVY1YuDu7/dkeDbOg7nVce3UqMB0Tn/AAyyjpKy7F9d0Opn\nTif+Pbn88q96vlH0mWbUPtsJSYK9ElWemQcHwd6R1R//AMG2BHG1pHy5qf44lGzFNne6+QVQ5GVf\ncOPyYtL+kqqWdRwx18ZyvtmlhjgHCu3ADJ2rumh0DlGHvKlAqUVhtpgvvxVTdu28OjnwfJnrv1aS\ntI4/1Pssk6xbj4fk4B2/hE1nKbUKda1r0ae5ndNqjm3AJ3K3fMB8WRCYzUM5pevfwi8fSJd2ae0s\n2pWZo0mvUqc13oa2VBcMvmztz9OJpeT2l31tXW56BqA1SRUbdu3drbTOrYnyTT6zrK0Fdmydi7ig\nPEzF+qlJ0bLAkqNpaXdyLprupzRZqK0DSXeF2qzMp6Xnk291J6mCwUY6goP9RnC6Dy0p3NZaLUzS\nZtwRucDqzKu7HUJ0NWtLSzzj3KLCn2NzpvKNFdqLHpLtJOOHSXdNi18rcfswZV+o1ityxB66dJj+\nZf6ZsrXUT4T5sxH1KfciWHg6bU6il8jhlVyfvSBVr4mtq3m7HH6Y09xwmcpJvYvGLSNR3Q6ubbPD\ng6kZ6uluX+qU1cJne3MOzZLNXQ4pjb3x2Kn8/gy2OW9XdaVB4Ajeba6ynajIN3ONVXPSVUAKsrfG\n4y2N7k70WH3K7wHnqW9mIVHFLHRRdzK21vLLEtGx9sp3uaXbLc43LtNN/e+pjtZdpbh87t+FLbtX\nzicWaTUmdEVaOmsKs2tFpz9i/VN5bPwE0xytGU40zZU+qOqZGpNH0M6kYjyCJuRhT5oKYi7PQb5r\nGXj3BVPKtwt6jngMOpb70k0bdarLWbvcLVI+CWZdoP3VkLluAznyNNzVK07aiEGFNCiQfJsWXnRa\nKOW1KoTUc9ZPRB8E7HuSUMCue3bRBHh3M7N/DOMvqys+FHnx1bpYXcro4pV28L0kH1Vb/FOT5Nn2\nOyAmtttCt0em6hvelZEBORt51qq9meDM2PnTaGCxRnq4Gb29o0QDVqJTB4BmOAYqzuqdVBUpOHQl\ngKinIO1trfmjWqaZQuVCV6a1FV9wVhkbo5p1nSoItKigp01JK01GFXczM35maRpGokJHhG265mkZ\nFEULxMYmWmCwlWiAZZyvLMdDPg3fwzqmYY/nOV5Z1BsxkZ6wM8dsnFtJUSU/rK9fnac3aJj2x8+i\nP4512sUulOXqjFVh2MyEjw7d3+KdD7tM0StWbqimFT5i/wAMsLuY0fe67eF0XPzV3f1TgavDE3mm\n8urfTKYo1KNWq9Q8+BTC4CN0F3bvhdAzLKuxKW52HLPkqL5qJDBObp3qu2MszVVTmj8rDJNvoOlp\na0KdCn1IDlsDLMzs7ftLfRK7fuvoc7LCse+wWqhR+VDIrd1i8P6PT1HHtqVH6P1aYnLNJGm5ZSHp\nEfKaN66ENrcCpjZzFUnPV3jbfzTiLTlrW2I7WVR3ZdzqhChDubh750mkTlLyruri3agLKpRNQqqM\naqOztu6lRR9vGYRaT3L1uVLysuia5UHgoUfeVW/qnT0s0adtWTvqaUqinwOq7gfoaQ7/AJL1al1T\nepT5inU2iph+ecc1SXe+3o9e3OOzj4JtNTtNtEIuSKaBQScnvdvfTpbSSaOiDfybvuQWHP3huqpy\nKB581GPfXLs23i3wu+MuRbumD0nQeUsBKESiWsqduKjUcVjXapT6Luzrt2NtILKOjNPfWdGl39zW\nqHHUDx3fWJkxmnsY+o/0epreqpAIIKkZDA5BWSHqDE8/aH3TWoUaVBabEUkFMPuTOxfDuHfSdW7s\nDb6YRCyn9I1QbNrbl4Ltzu+FOmKtHF02y4Lu7p0qRq1HCU1XLVGOAqzOplXt2wc5VWGOOV3r1Tzj\nyw5a3d4vMvUxRRmK0aZIR/K/+8+mbnXO6LXu6NHT7JalLdTtaDVgc169XoK1Po/o6XR4nrPGXWwc\nDo+Uw2NuB4hlIPghcnKK4IIYbgcD7IjlGrYAfG5VTeQeG9V6W35M12hXJa1qbuK069VKZ6+/6WPt\nZpZq0TFnK8t7k0q4ZQCXoKSpOAW3Mufyzl9Mt/bVwWuF2opROj1O3zm+idtf2dK51Swo1yVpVdyP\n2E7d7Km7yttEzy50Wjp5ZaSOqVi3NAndh9q8N/xcdX0zCUkjpjG+5z3K/wBq0uat7SlT5pafOVrg\ncXe4bd73ub4AVuztkLTNo2uihekDwGO9aae8u8nHV2EZkY3VdNuxyAG3Bc/56MyctXY2nFJUXVoe\nvHauw4OMnjOq0rXGcjc3DqnnSjqtdcnnH3kszEOQS31ZNteU1+nGk9Xh15BcfmBhp8mGlF8aXdhn\nCfG4YnJcoN1nqAdCei6VlJ456XVOgs6W1g2e2T9W0eheVKTVi+KavgK23d3vBuHyYU9qFI6Szulq\nUkqr3tRFcfNaJqNK2ocu0t1NtbW1SotF3Sm2HJ272Zdyr86R7jlzqL/o7Pb4fe6hP1eMpTb2FFlO\n0r3ly53VFB4NRYgZ+FtkGlyi1msrstuwRNu9toQL33+8PS71uqOkVa1Om9wuKhRsjHwdzbf2bZZK\nnbIaORsLW4prTvFHvaurCpnq2t8KWjaavRq0qdTnFG5VJUugIO1dw25nF2nI+lXSpWWrUVMVTb0A\nwOdvenpDoqWDcPB2x7k3yetW5xiKrqopIFeoejW2bqo6IHUzKPqzoyzjNbmajTNprNyhuE2Ore8t\nnaQ3w/k+eZo15orpadvUp0egHSpVUNgB6lFk3IWPwu9wfmyQb1B8L9hnBJ09uxvGKaN8lx1ce2Om\nt5ZzianTB4v256j/AHSQdUpHqJPlCP8A3SVkDgg5StuoVlHbTbEqJGqdPm61OmOsioUUk/J4EtLV\nvq4dHAzxR+JGPgyornaGPOKx6TABCE+F0t24GdeJ/JlKHwb7kLWYXSEJuGHV6wBwN37P2S6LFurz\nTzzY1ayOrUd2Q24L/i+NOutuU+sHvVRfIKP/AFmOaGp2iyWxeVkeqby0bgJQtvrutt1VCPNTRcfs\nk6hc625/1mqM+A7f5SMe2zInEv6kZIU9pPlJnn8afqzHp3dx+LUx++ZqclLqpjna9VuOeNQt/OdU\nZruzN4i+KupUF76tTHkNQCMPrtmeh7Zobm6IXnEJZm6KiUpS5BZ66r+bh/dNhpfIkUqlOoHbNOrS\nqDIHfKysvZLrJG9irxmx5YDbWqIesVGyPrScl2G06nUf4NtsA8LrXakv5UkHug8Ltz2naxEzo7Aa\nfTqP1K1UKueBqrVq4+zMu5JlYpo09KmQwz15WdJo3dJsbGl7Xehc1KqvVLlEphC+74zVB8XwTnKD\nlqq8et1E6u25MW54mmMniSe1pyOVOzp0prcG7sdue8sbhvnVKa/w5jNXuuVCfetObq6zUJ6X1RNp\nQ5N0B1IvmxJdPQaI+Av2Sry18FekjnD3UNRYdCypr5TzjRluXutsehRpL5qOf4nnXrpNIfAX7BHk\n02l8RfsEr1vodJHCryp5Rsf0yrx6va9sMf8Ay5195yk1cYFChbsvNp79VLhy+zpdBeHfbpsktkHY\nPJwkqkoHYOHZiU630T00cs+rcon7bWn5BR3H80w55QP317SQY6qdvRU+fcyEzrQB4JkCVeVDpo4q\nvpmsvjdqtb5qhE/hAkinYVqaIK1VqzLTKb2OWPS3ZZvhTqKs1uqdXkl8GS5xTDxKnRwPKGnhj5si\ncXqPCop8J4H5s63lZUYVDx7cTndTs2a19sY6KXS0854jcnH8yrO2bp2ykDZtxC+YTorHQqdZVdkU\nkDZuPXtXsnJUKvQTyKolg8jKgekxz8LBTwdFeP8AFOX1Mv8AKaNodxqnydojqQDw8IsaJTHwR9k6\nACYKiec8j+TarNBX05sYpsFPYxGQPokBLGrTrpUr1OcGGRCEChGbbxnTVVGYxd0wy4+kH5UweRmi\nijmNfskVkqZOdzKBk42sj/4pyOt3Bo03LIaiFVUFe+FXc3WOpVx2zr9VQsVye96hNdUtc9kus7VJ\nmihfY43RbivchkXdSIwoYgFBu70N2x655JXBOWqAn5hljaNptNVDbQWIzuI6pt0t1+L+ybLMu6M5\n4/gqClyRrfHz5lkqjyGdiuS/F1B4AS3admnxR9kk+1E+KPsl1nlyZ6EisX7nlJe1z5N3GbLkhodr\nbXe9FCVaSMwq1xUFMbui3NVW4b9rN4Z3dS3B7JAvNIpN0nQMQOGQCBLrPLu2NCfwcFy+v6vPPzBF\nzS4s60Km90To8SijP0/umOSN3zlGoKatt3qSrBEZKrL0n2t33gm/1GzWm2UGzIwTTJQ/eWa5rQMc\nsareDdWqHH7ZL9Y1sXWBPc0irWrXHvlCugoVMm4x72WXtSquBF6/srPubLEDA3s7gfNDHozZVbbB\nxgYkZ6I8E5snq32No4aOYfSqfxB1+CR6ug0W+B9O5x/OdZUoDwTFCiCRw7Zgs75NnBVujnbXk8qj\no0/pJzJA5MVm4rV2ce9KjhO0pW/AZ7BJCUxL9eXJi4R4Nwtkc54TY0EAHHqxxjZM1mra9bUEcPVQ\nNjbs3AsPgno+SeikzgC5063Sg7pSVXqvtp46ILu+3OF77wzaJZUgABTTqUFtgyZwusd0OzHMCilW\nslBt5GBTVnVNqbWY528W7Jz+pd0bUKvC2RaIzwKqHcfWqcJO6JSLPrpTpmqvBQVVyDgIFZdv8StO\nC5T69b0kxzqlzTZFCHdxXo5Vl83XOetXvrpLhbms7l6aspdupkfcQqqOj0cxj/QYZKauM7N4HzWb\nd/iltSrdhxbNiO6ElKmKdrbs21VQPUfaBt+QoO77ZoRr+pOHWnVNIVKtWsVQbCC7bm2tjO2byy5O\nU8Zx+2bW00mmCMLI6kfgso3szibOzuBVStUdnO7JZiWJ+lp0oSqf5HE3psBjgB9keWzmE5WzRRSR\noEtn8v2R+lZv4T9M6BLbyRYoSgRoHtWx1/tnPXWj09xzTRsMx3FRO9qW5PgmrrW/SPDtk6mvkml8\nmhtNMThtRR5lAnSWVggx0f2RulRx2Te2tHgPKJWWR8k0hNtaKOz7BNpbWwHZMUEkykJWM3ZVr6FU\n6Aj60R4B9kVTEkUxNlNlGjFOmAOqLRBkcB1+CLCzIWXjN2UlHY4buiZNxn5K8ZDsKm7TNo66V44I\nB+Cy7ul96dFy2sNyc58nB8m2czyU40r+lxPRo1hns27lb+JZ6Cdqzma3ohoxBBHXnIPgaWdycrip\nb02zl9q7z279vSlYHwTuOQN1lHpk8V2kDw99unFks6InVqIsRsGKBnO5F1EyYlWgTMCU1DSOiOrG\nRF75RyGkdmC0b3GYLSHIlIy5kPUVyp82ZJJkeuc8PtkwlTTvsK2orXlWmWY/KjHJixNzbahbZ+DR\nqUx14rdP9+1ZteWdvsGflflkXufVCty6DGKlLLfUbo/vaernkmrTOaCp0zlrEnvD1gsCPAyywe58\nPe6vnpDP3pwFzTalc1lYYIrP/FLA5BD3lz/xMZ8O1V/vnJ6iVwN4o6aYJgxjRaeW5bnRFOjFTrjZ\nEUzRLGZMukzRX9HjwHbIZpTb3C8TIdQSNRvHsO6XU4bT2HgJtqImjpDBGJu7Z8geaXhIrNX3JyYj\npMjJHS02T3MdIvMRVPA+ZuEbLxLvwPmltZGk0WoDPXNeiDjNje9chkSras2j2IVwkimkJPrCMFZz\nye5sRDSEdtaAz1R4pJFnTkJiyQlPo/RI+6bLZ0fomtdMH+6XbMyrrvVdRum98q1MdRCnYv3VmLLR\n6nEEHpDBPXn6Z29LSFB70fZNjQsFA6v2T2Hl+EcKx77nGWHJ/HAqMHrGOM31noSr2DyYE36W/kki\nlTlXJsukkaYWO3BUDzCJq6fxyPBgjE3ppeSY5qRTYbSNPRtSOH7hJNK1wcycKPkj1OjL6SrZENER\nS282CUPJFpQldJWzXih5JjmJtDbmJ5oyjVF0zVvSmuuaPHqnRvRkK6tpRssnuaVKJyJubanwHmjK\nUQDJ9AcJlJ2SLpiSqIjCSQkRYJFNZIThIiNHQZspWZtEkNM7+MYBmSZZMhqxV9SFSmykZyrYz8bb\nOB0Onzd1c0zw321VQvaWV0ZR93dO8DeXsnC8o1ancCuvBldmI6ty/wDtnoendxOXKqZrK46R854e\nCb/kW4WvggnKtgjq+tNPqoBfcnFWUMD86O8n7krXpZOOmuTnht3dKY5otGuPdll75nnZBFfMVzk4\nJSXY3UbJvOTAqyHzkBUmbZOmjZBopWkNKkdRpTUKRIzMZjZaJ3w2KQ6xkdzMs8bYyLZFI57lral1\nRvgoGLt2KJzXJBj7cApcU21RUbPDmuw9L5WJZNpaUq781WQPTZTvQ9R2r0d31tsi3+j21u6m2o00\n4bXZBjK/+5Z6mPfAm/s53/6or/ug2bCutUdIVEVdoBypVdvSnQchqDJbAluDszBfi+SbK5pjnabN\n1NTdAp4qW37s7fjdmZPZCFUEAYXGFGBMcibxotGSToGeMs8w7iMM08uWx2xQ9vmC8Z3Q3zKyUNVz\nIFU/vk6q0gVG4mQbRYul1zaWk0qOeybWxfo8fDLRdCRsFMVmMK8yW4TazChbNEOeifNGiZlzwiyU\njXXfXIdSSbluJkYtM5SNEiPVkdgZJqHjG5k2ajQWS7QcY0Fki3WE9yrJ3Z9E19U8ZPPV9E19QGaN\nlRz2vHEpSa1KC0p7WhWcTkyMlKOpSjwSOIksolGxnmpgU5K2TASW0kNjK0Y/SoxdFeMlovHql6Ib\nI/NYjqUhHKq+T9sVRlGibGmpyPVST3EjVBMpkxIrLI1dJNcRmsJzSdGxrmp8Y8OEKgiQZm2WHUaO\nq0jAxSvJTKtErdMhpHyZlWkqRFEkP5f2zBfyn7YxuhmSpCh4v5f2zRcr7TcgKk7irHbgYm4tqZd0\nT4zKoOCek3zZI5XadTZObWptIGC2AV6PZPT9HtdnPme9IrfRqrmnVpMu+pSK7Tg9JG3Njb5OlG7a\ng7NuqEoo6lHRO7986nkboOx69w/ONS3UrdjSplsszqzd7x+L2cN07L/wfbYLsjHJ3DcxGF+CNs19\nRVOzODdmnsqnvaYYnoqM54x3nYxVqIGdKfeozIB4Nsb5yeJke52RWxL5z/OYtakghotWMysk2dGr\nH1qzXUsx9SZFgnGpECpI+ZjMakCSXiTWjDPGmeNSJo33JO4pVHrKGHO01QsmP9k3en726cLy45dC\nlemzpBQtKs6XNeoDncu7oUh8Fdy9c0/KXRa9Wu1SlXamGVAVUHjt+aZAs+TIDh6paq/a7dW7w/8A\nrPSjnh01Hgx6LcrJ/dD1p+atjRIRqDNVFbPTKuq9BlxhuP8A6TcXPdG072hhNzXxoICvN+9pcNtV\n+lnsXd2Rq+tKbIFKhuGMYkJNCof7tPPtmS9UkqaJeHezfadd87Rp1cY300bHzl3R4Exu0QKqqBgB\nVUDsAj88zJO22jpgttxODM44TMCJlqZekM1FkOqvGTXWMVFkWWiR1WbC0OBIgWSaMlMl0TA0UXjI\nmCTLWyg6WiHfETmN1YtgiVzIjiSKnXGakhyZokMERwU4kCPATNk/AjEfoiIxF0+ElAldkhMJLBkZ\nx++WsG5NOYFIyaKeZk0p9NGJ5dkIU+Mk0KIieb4yXQXql0irYipQ4dX0yKUm2rDhgSBtkMIaorgy\nYw4yMBxj+7Mi9iaM1ImlBoU5nJomhxoxXkgiMVpjIskRyI1VXhJBEQ6znn2NEa6qsaIkyqkaCeeY\nsuMgTIEfCQ2iRYQ0BFBY5iAEJgQVgI5tmAJaw1sTf/Fi0aQt6NjXBC7XrqKeKj7ek+/IPGcprN9f\nV2wqLRX/AHjHe+35q979s6EH9ki3ODNl6h8mSx8kbROWVXT7anarp9W5ZS7VblaiKHrO7Mx6Q6Xw\nfuzGpco9RvRtVDZrliCKo3j4u40/hDz48MEwOwfZHQ4Hk80ZfUyfZlliSeyGNPsnVcO7OxOS5PFm\nk1aMKZjwnHKVuzXSJFGKCjwRWYkmZt7k0OpFs0ZUxRixQ6GiS8wrTEhsUZiXmQZhjIsmiNVEj1jJ\nNUSCZopbBCXjlERsxdAzOUi5KWOKY2pjizJkVQqZExmZErYMNI1QeeSGEZeLJTG1EfpxsCOpCZI8\nJhogNFFpayoCNuYsNGzDZKRErLGCsmVVjDStl0ICxQmBFgySfgAIsJBY4JCIZgiNMI+Yy8WFwdJT\nMfC5jCL++Sqc+sXY8sjVEgjYjtWIAkkMkg5kOqMGSweEiXEhhDZmcxBmZjJ0XAtMo0ZcxSGZNiiX\nujLmZECspJlojYiajRcHEwky6IrRBElMI2VmTZdEeBjxiT5pRskRMgRYWDSrkBEDMqIESNTJoSeq\nRaslmR6wjUyaIZHGBijFBJVyJofoHhHhGqSx5RKWTRgQIjgWZKyNSIEII5CDxqA3FCYAmRIbBhon\nMU0wZGoDNXtkEyfVWRHWTq2LJDZEwBFzEo5FhaEyQkaEfT+Uq2BOZkNFbYASAJzG3jxESVgCUEdV\nYjEdT6IBjbMgRwDhEPJsCSsSwi4l5AWw08adcxxoiCRgiZEcAEwBIsvQpIqYBihFlWjGYh46REER\nZNHQCSKMjsYqm8+tTR5bQ/XxGDMuYyXhshIk7pGqEmOUTE1TIcti0YpjRgDAxJmMpF1EwwiUMy4m\nAMTGUmTpJFKZdogNATNyCVCliXMCYiZykvgvRhzGsx0rETFslCSYCBikWZuTLUBESYp4jMo2xQAQ\nJmQYgmRbJRgmMVY+saqiLJIpHGLiKgikEzlIuSKcdWM0xHBK3YYtTxi8RtBHGkFaMEzMbMXFkgDF\ndkbIgHkWyDLROZlohpKYobrP5pFcSRUbhI7SX2LpCQJlREhYpTxEo2TQ6FjimYEziRYpjuYl2mEM\nyRFimYDRRmMCZEWKYGYSKxCEKMqYGEQ+ZIXcViJYwDTB65Fk0NuI3HasaMWKMYhiZhILABMiAEzA\nMgwMxEmAbsvMo3giIpZ9TrPNpiyTEYmSYkSHIlIWgmWEzSYcYmq0pKRIgwiTAGZuRKByBGi0DMTC\nUi6FoYotGg0UrTJyZahwQmMzJaUlIgwx4RIWKJBmDwEq2ShJEQzzLNG5m2SZBhATIlHKiaCYAiiZ\niUcrAESPVMkFow4MWyURyIpI4VmCJDZZCkMdEY7ZIAyJWwxSiYYxaL+yDJFkCBiLmNsUo4RYEOfJ\nGTmPssxtkChsZgRHwsbcQgRTI7mSavXGaicMwWQ3mZ7ZgCL2yGWQ5SMeSM0o8kqyTO2IwRHwJgrJ\nsixvGYtFgFjyLFkMbAmCI+UiCsWQIAmGWLCRb0oQWxEYTGY66xOBBcbbjGiI+2IhlkMDIgIsrExd\nkoyDCYEAYBnMMzBEITBvGIiZkwQT6WzgoxEx2NNIbFGczOZjEwxlGyUjBMQWiHqRIzMpSL6RbRom\nZJiJjJkpCxFhoyJkTPVRND+eEzuxGt0UGGeMq2KHFEw8UrCJdpVslKhozEyYESkpUTRjtixEoItT\nM2yTOJlFhF7fPIAzVERHaqHw/RGcGLBg4iCYp+qJSUbJW4IeMmL1SKI8Dw/lIslqh6iIphM0DgRB\nPGRZFAU4RKrHm6vojdLqk3sSIcQVYp4njIsA44xdWnwik6oiq8WRRDuExI7eCS67ZEiAQWoSBFrA\nrBBIbLC0jyRCCOSNQHAIsrEUzHhFlaGiIumMfTEERdMwmS0OERp1jwmJJUbSKYxNQRBMWTQl40RF\nlYYk2WGWmI6yxsyABSIKRwNM9chEojsuIkR1hG2EWAMAYkGKkkG8CQJnkz3S+u+KaT6PfeuRI9kr\nrviulej3vrc+s/XkeP8AuQPWpiCJ5O90vrvimk+j33rkx7pXXPFNK9HvfW5V+lmSvWQPV7vGXeeU\nz7JLXD+qaV6Pe+txPuj9c8U0r0e99blH6PJyWXrcf2erAsCZ5U90hrfimlej3vrcD7JDXPFNK9Hv\nfW5R+hyfRP7uPl+D1QWmCJ5W90brfiulej3vrcyPZH634ppX4F563Mn+PyvjySvXYvvweqRCeVT7\nI/W/FNK/AvfW4e6P1vxTSvR731uR7dl+vJP7+L78HqrMcp08zyj7o/W/FNK/AvfW4tPZJa4P1TSv\nR731uR7dl+vJH72Pl+D1oiRLrPKPumNd8U0n0e+9ciT7JXXfFNK9HvvW5D/G5vivJP7+Ll+D1W6g\nTCCeU29klrh/VNK9HvfW4e6R1zxXSvR731uUf4zN9eR+9i5fg9WCAE8pe6R1zxXSvR731uZHsktc\n8U0r0e99bke15vryP3sXL8HrOksWBPJg9ktrnimk+j33rkz7pfXPFNJ9HvvXIf4vN9eR+9i5fg9X\nVTIheeWW9knrh/VNK9HvvW40fZG634rpf4F763I9qzfXkn9/Fy/B6odphWnlhvZGa0f1XS/wL31u\nYHsi9a8V0v8AAvfW5X2nN9eSV6/Evl+D1SrR4NPKI9kZrXiul/gXvrcV7o/W/FNK9HvfW5HtGb68\nkv8AIYn8vwesUeDN2zyf7pDW/FdK9HvfW4e6R1vxTSvR731uPaM/15I/fxcvwesTUzwmaJnk0eyR\n1zxXSvR731uKHsk9cH6ppXo9963HtOf68ke4YuX4PVzNE1G4CeUvdJa54ppXo9763MH2SOtn9V0r\n0e99bj2nP9eSf38XL8Hq4PMOZ5R90frfiulej3vrcyfZIa34rpXo9763HtGb68kfv4uX4PUjtGjP\nLh9kXrXiul/gXnrcD7IrWvFdL/AvfW49ozfXkv7ji+/B6kBmJ5cHsita8V0v8C99bgfZFa14rpf4\nF563If4jP9eR7ji5fg9VUuMcUTymvsjdbH6rpX4F763Fe6Q1vxXSvR731uR7Pn+vI9xxcvwergI6\nnVPJvukdc8U0r0e99bmV9knrg/VdK9HvfW49nz/Xke44uX4PVzrEjhPKnulNc8U0n0e99bmD7JPX\nPFNK9HvvW49nz/Xke4YuX4PWKNFieSvdJa54ppXo9763FD2SmueK6V6Pfety3tOf68lX+Qxcvwes\nHjDzyqfZKa4f1TSfwL31uJPskdb8U0r0e99bke0Z/ryW9xxcvwerVaYInlP3R+t+K6V6Pe+tzI9k\nlrnimlej3vrclfiM/wBeR7ji5fg9UmIZZ5YPskNb8V0r0e99bmPdH634rpX4F763HtOf68j3HFy/\nB6kYTIE8sH2Rut+K6V+Be+tzPujdb8V0v8C99bkL8Rn+vI9xxcvwepCYhp5c90ZrXiul/gXvrcD7\nIvWvFdL/AAL31uH+Iz/Xke44uX4PUGJgieX/AHRGteK6X+Be+tw90RrXiul/gXvrce0Z/ryPccXL\n8FNwhCfUHgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgB\nCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQ\ngBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAE\nIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhC\nAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQhCAEIQgBCEIAQ\nhCAEIQgBCEIAQhCAf//Z\n",
      "text/html": [
       "\n",
       "        <iframe\n",
       "            width=\"400\"\n",
       "            height=\"300\"\n",
       "            src=\"https://www.youtube.com/embed/iguPncD11bI\"\n",
       "            frameborder=\"0\"\n",
       "            allowfullscreen\n",
       "        ></iframe>\n",
       "        "
      ],
      "text/plain": [
       "<IPython.lib.display.YouTubeVideo at 0x107ea1d30>"
      ]
     },
     "execution_count": 43,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "YouTubeVideo('iguPncD11bI')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "anaconda-cloud": {},
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.6.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 1
}
